#!/bin/sh
# make-bindist.sh for the HPUX ports
#
# written by Marco van den Heuvel <blackystardust68@yahoo.com>
#
# make-bindist.sh <strip> <perl> <vice-version> <prefix> <hostcpu> <system> <zip|nozip> <topsrcdir> <dtv-version>
#                 $1      $2     $3             $4       $5        $6       $7          $8          $9

STRIP=$1
PERL=$2
VICEVERSION=$3
PREFIX=$4
CPU=$5
SYSTEM=$6
ZIPKIND=$7
TOPSRCDIR=$8
DTVVERSION=$9

UUID=`uuidgen`
DATESTRING=`$PERL src/arch/unix/hpux/getnow.pl`
UNAMES=`uname -s`
UNAMER=`uname -r`
UNAMEM=`uname -m`
UNAMECONCAT="$UNAMES_$UNAMER_$UNAMEM"

getsize()
{
  gotsize=$2
}

getsum()
{
  gotsum=$1
}

installfile()
{
# installfile <source-file> <dest-path> <info-file> <installed-path> <total size var> <mode>
#             $1            $2          $3          $4               $5               $6

  check=`cksum $1`
  moddate=`$PERL src/arch/unix/hpux/getdate.pl $1`
  getsize $check
  getsum $check
  cp $1 $2$4
  chmod $6 $2$4
  echo >>$3 file
  echo >>$3 path $4
  echo >>$3 type f
  echo >>$3 size $gotsize
  echo >>$3 cksum $gotsum
  echo >>$3 mode $6
  echo >>$3 uid 0
  echo >>$3 gid 3
  echo >>$3 mtime $moddate
  if test x"$5" = "xman"; then
    mantotal=`expr $mantotal + $gotsize`
  else
    runtotal=`expr $runtotal + $gotsize`
  fi
}

if test x"$PREFIX" != "x/usr/local"; then
  echo Error: installation path is not /usr/local
  exit 1
fi

if [ ! -e src/x64 -o ! -e src/x64dtv -o ! -e src/x128 -o ! -e src/xvic -o ! -e src/xpet -o ! -e src/xplus4 -o ! -e src/xcbm2 -o ! -e src/c1541 -o ! -e src/petcat -o ! -e src/cartconv ]
then
  echo Error: executable file\(s\) not found, do a \"make all\" first
  exit 1
fi

echo Generating HPUX port binary distribution.
rm -f -r catalog viceplus runtmp mantmp

# Prepare directory structure
mkdir -p catalog/dfiles
mkdir -p catalog/viceplus/pfiles
mkdir -p catalog/viceplus/viceplus-MAN
mkdir -p catalog/viceplus/viceplus-RUN
mkdir -p viceplus/viceplus-MAN/usr/local/man/man1
mkdir -p viceplus/viceplus-RUN/usr/local/bin
mkdir -p viceplus/viceplus-RUN/usr/local/lib/viceplus/VIC20
mkdir -p viceplus/viceplus-RUN/usr/local/lib/viceplus/PRINTER
mkdir -p viceplus/viceplus-RUN/usr/local/lib/viceplus/PLUS4
mkdir -p viceplus/viceplus-RUN/usr/local/lib/viceplus/PET
mkdir -p viceplus/viceplus-RUN/usr/local/lib/viceplus/DRIVES
mkdir -p viceplus/viceplus-RUN/usr/local/lib/viceplus/doc/images
mkdir -p viceplus/viceplus-RUN/usr/local/lib/viceplus/CBM-II
mkdir -p viceplus/viceplus-RUN/usr/local/lib/viceplus/C64DTV
mkdir -p viceplus/viceplus-RUN/usr/local/lib/viceplus/C64
mkdir -p viceplus/viceplus-RUN/usr/local/lib/viceplus/C128
mkdir -p viceplus/viceplus-RUN/usr/local/info

# Install and prepare viceplus-RUN
runtotal=0
$STRIP src/c1541
installfile src/c1541 viceplus/viceplus-RUN runtmp /usr/local/bin/c1541 run 0755
$STRIP src/cartconv
installfile src/cartconv viceplus/viceplus-RUN runtmp /usr/local/bin/cartconv run 0755
$STRIP src/petcat
installfile src/petcat viceplus/viceplus-RUN runtmp /usr/local/bin/petcat run 0755
installfile src/arch/unix/vsid viceplus/viceplus-RUN runtmp /usr/local/bin/vsid run 0755
$STRIP src/x128
installfile src/x128 viceplus/viceplus-RUN runtmp /usr/local/bin/x128 run 0755
$STRIP src/x64
installfile src/x64 viceplus/viceplus-RUN runtmp /usr/local/bin/x64 run 0755
$STRIP src/x64dtv
installfile src/x64dtv viceplus/viceplus-RUN runtmp /usr/local/bin/x64dtv run 0755
$STRIP src/xcbm2
installfile src/xcbm2 viceplus/viceplus-RUN runtmp /usr/local/bin/xcbm2 run 0755
$STRIP src/xpet
installfile src/xpet viceplus/viceplus-RUN runtmp /usr/local/bin/xpet run 0755
$STRIP src/xplus4
installfile src/xplus4 viceplus/viceplus-RUN runtmp /usr/local/bin/xplus4 run 0755
$STRIP src/xvic
installfile src/xvic viceplus/viceplus-RUN runtmp /usr/local/bin/xvic run 0755
installfile doc/vice.info viceplus/viceplus-RUN runtmp /usr/local/info/vice.info run 0644
installfile data/C128/basic64 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/basic64 run 0644
installfile data/C128/basichi viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/basichi run 0644
installfile data/C128/basiclo viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/basiclo run 0644
installfile data/C128/c64hq.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/c64hq.vpl run 0644
installfile data/C128/c64s.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/c64s.vpl run 0644
installfile data/C128/ccs64.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/ccs64.vpl run 0644
installfile data/C128/chargde viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/chargde run 0644
installfile data/C128/chargen viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/chargen run 0644
installfile data/C128/chargfr viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/chargfr run 0644
installfile data/C128/chargse viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/chargse run 0644
installfile data/C128/default.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/default.vpl run 0644
installfile data/C128/default.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/default.vrs run 0644
installfile data/C128/frodo.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/frodo.vpl run 0644
installfile data/C128/godot.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/godot.vpl run 0644
installfile data/C128/kernal viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/kernal run 0644
installfile data/C128/kernal64 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/kernal64 run 0644
installfile data/C128/kernalde viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/kernalde run 0644
installfile data/C128/kernalfi viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/kernalfi run 0644
installfile data/C128/kernalfr viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/kernalfr run 0644
installfile data/C128/kernalit viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/kernalit run 0644
installfile data/C128/kernalno viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/kernalno run 0644
installfile data/C128/kernalse viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/kernalse run 0644
installfile data/C128/pc64.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/pc64.vpl run 0644
installfile data/C128/vdc_deft.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/vdc_deft.vpl run 0644
installfile data/C128/vice.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/vice.vpl run 0644
installfile data/C128/x11_pos.vkm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/x11_pos.vkm run 0644
installfile data/C128/x11_sym.vkm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C128/x11_sym.vkm run 0644
installfile data/C64/basic viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64/basic run 0644
installfile data/C64/c64hq.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64/c64hq.vpl run 0644
installfile data/C64/c64mem.sym viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64/c64mem.sym run 0644
installfile data/C64/c64s.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64/c64s.vpl run 0644
installfile data/C64/ccs64.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64/ccs64.vpl run 0644
installfile data/C64/chargen viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64/chargen run 0644
installfile data/C64/default.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64/default.vpl run 0644
installfile data/C64/default.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64/default.vrs run 0644
installfile data/C64/frodo.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64/frodo.vpl run 0644
installfile data/C64/godot.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64/godot.vpl run 0644
installfile data/C64/kernal viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64/kernal run 0644
installfile data/C64/pc64.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64/pc64.vpl run 0644
installfile data/C64/vice.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64/vice.vpl run 0644
installfile data/C64/x11_pos.vkm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64/x11_pos.vkm run 0644
installfile data/C64/x11_sym.vkm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64/x11_sym.vkm run 0644
installfile data/C64DTV/basic viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/basic run 0644
installfile data/C64DTV/c64hq.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/c64hq.vpl run 0644
installfile data/C64DTV/c64mem.sym viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/c64mem.sym run 0644
installfile data/C64DTV/c64s.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/c64s.vpl run 0644
installfile data/C64DTV/ccs64.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/ccs64.vpl run 0644
installfile data/C64DTV/chargen viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/chargen run 0644
installfile data/C64DTV/default.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/default.vpl run 0644
installfile data/C64DTV/default.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/default.vrs run 0644
installfile data/C64DTV/dtvrom.bin viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/dtvrom.bin run 0644
installfile data/C64DTV/frodo.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/frodo.vpl run 0644
installfile data/C64DTV/godot.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/godot.vpl run 0644
installfile data/C64DTV/kernal viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/kernal run 0644
installfile data/C64DTV/pc64.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/pc64.vpl run 0644
installfile data/C64DTV/vice.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/vice.vpl run 0644
installfile data/C64DTV/x11_pos.vkm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/x11_pos.vkm run 0644
installfile data/C64DTV/x11_sym.vkm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/C64DTV/x11_sym.vkm run 0644
installfile data/CBM-II/amber.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/amber.vpl run 0644
installfile data/CBM-II/basic.128 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/basic.128 run 0644
installfile data/CBM-II/basic.256 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/basic.256 run 0644
installfile data/CBM-II/basic.500 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/basic.500 run 0644
installfile data/CBM-II/c64hq.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/c64hq.vpl run 0644
installfile data/CBM-II/c64s.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/c64s.vpl run 0644
installfile data/CBM-II/ccs64.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/ccs64.vpl run 0644
installfile data/CBM-II/chargen.500 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/chargen.500 run 0644
installfile data/CBM-II/chargen.600 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/chargen.600 run 0644
installfile data/CBM-II/chargen.700 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/chargen.700 run 0644
installfile data/CBM-II/default.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/default.vpl run 0644
installfile data/CBM-II/frodo.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/frodo.vpl run 0644
installfile data/CBM-II/godot.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/godot.vpl run 0644
installfile data/CBM-II/green.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/green.vpl run 0644
installfile data/CBM-II/kernal viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/kernal run 0644
installfile data/CBM-II/kernal.500 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/kernal.500 run 0644
installfile data/CBM-II/pc64.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/pc64.vpl run 0644
installfile data/CBM-II/rom128h.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/rom128h.vrs run 0644
installfile data/CBM-II/rom128l.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/rom128l.vrs run 0644
installfile data/CBM-II/rom256h.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/rom256h.vrs run 0644
installfile data/CBM-II/rom256l.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/rom256l.vrs run 0644
installfile data/CBM-II/rom500.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/rom500.vrs run 0644
installfile data/CBM-II/white.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/white.vpl run 0644
installfile data/CBM-II/x11_buks.vkm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/CBM-II/x11_buks.vkm run 0644
installfile doc/html/plain/64doc.txt viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/64doc.txt run 0644
installfile doc/html/plain/BUGS viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/BUGS run 0644
installfile doc/html/plain/COPYING viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/COPYING run 0644
installfile doc/html/plain/NEWS viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/NEWS run 0644
installfile doc/NLS-Howto.txt viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/NLS-Howto.txt run 0644
installfile doc/html/plain/PETdoc.txt viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/PETdoc.txt run 0644
installfile doc/html/plain/TODO viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/TODO run 0644
installfile doc/html/plain/Walkthrough-Howto.txt viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/Walkthrough-Howto.txt run 0644
installfile doc/html/amigaos.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/amigaos.html run 0644
installfile doc/html/beos.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/beos.html run 0644
installfile doc/cartconv.txt viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/cartconv.txt run 0644
installfile doc/html/plain/cbm_basic_tokens.txt viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/cbm_basic_tokens.txt run 0644
installfile doc/html/plain/drive_info.txt viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/drive_info.txt run 0644
installfile doc/iec-bus.txt viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/iec-bus.txt run 0644
installfile doc/html/index.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/index.html run 0644
installfile doc/html/macosx.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/macosx.html run 0644
installfile doc/mon.txt viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/mon.txt run 0644
installfile doc/html/images/new.gif viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/images/new.gif run 0644
installfile doc/openGLsync-howto.txt viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/openGLsync-howto.txt run 0644
installfile doc/html/plain/serial.txt viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/serial.txt run 0644
installfile doc/html/solaris.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/solaris.html run 0644
installfile doc/html/images/vice-logo.jpg viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/images/vice-logo.jpg run 0644
installfile doc/html/vice_1.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_1.html run 0644
installfile doc/html/vice_2.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_2.html run 0644
installfile doc/html/vice_3.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_3.html run 0644
installfile doc/html/vice_4.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_4.html run 0644
installfile doc/html/vice_5.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_5.html run 0644
installfile doc/html/vice_6.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_6.html run 0644
installfile doc/html/vice_7.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_7.html run 0644
installfile doc/html/vice_8.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_8.html run 0644
installfile doc/html/vice_9.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_9.html run 0644
installfile doc/html/vice_10.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_10.html run 0644
installfile doc/html/vice_11.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_11.html run 0644
installfile doc/html/vice_12.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_12.html run 0644
installfile doc/html/vice_13.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_13.html run 0644
installfile doc/html/vice_14.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_14.html run 0644
installfile doc/html/vice_15.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_15.html run 0644
installfile doc/html/vice_16.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_16.html run 0644
installfile doc/html/vice_toc.html viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/doc/vice_toc.html run 0644
installfile data/DRIVES/d1541II viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/DRIVES/d1541II run 0644
installfile data/DRIVES/d1571cr viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/DRIVES/d1571cr run 0644
installfile data/DRIVES/dos1001 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/DRIVES/dos1001 run 0644
installfile data/DRIVES/dos1541 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/DRIVES/dos1541 run 0644
installfile data/DRIVES/dos1551 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/DRIVES/dos1551 run 0644
installfile data/DRIVES/dos1570 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/DRIVES/dos1570 run 0644
installfile data/DRIVES/dos1571 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/DRIVES/dos1571 run 0644
installfile data/DRIVES/dos1581 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/DRIVES/dos1581 run 0644
installfile data/DRIVES/dos2031 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/DRIVES/dos2031 run 0644
installfile data/DRIVES/dos2040 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/DRIVES/dos2040 run 0644
installfile data/DRIVES/dos3040 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/DRIVES/dos3040 run 0644
installfile data/DRIVES/dos4040 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/DRIVES/dos4040 run 0644
installfile data/PET/amber.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/amber.vpl run 0644
installfile data/PET/basic1 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/basic1 run 0644
installfile data/PET/basic2 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/basic2 run 0644
installfile data/PET/basic4 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/basic4 run 0644
installfile data/PET/chargen viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/chargen run 0644
installfile data/PET/chargen.de viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/chargen.de run 0644
installfile data/PET/edit1g viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/edit1g run 0644
installfile data/PET/edit2b viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/edit2b run 0644
installfile data/PET/edit2g viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/edit2g run 0644
installfile data/PET/edit4b40 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/edit4b40 run 0644
installfile data/PET/edit4b80 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/edit4b80 run 0644
installfile data/PET/edit4g40 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/edit4g40 run 0644
installfile data/PET/green.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/green.vpl run 0644
installfile data/PET/kernal1 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/kernal1 run 0644
installfile data/PET/kernal2 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/kernal2 run 0644
installfile data/PET/kernal4 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/kernal4 run 0644
installfile data/PET/rom1g.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/rom1g.vrs run 0644
installfile data/PET/rom2b.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/rom2b.vrs run 0644
installfile data/PET/rom2g.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/rom2g.vrs run 0644
installfile data/PET/rom4b40.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/rom4b40.vrs run 0644
installfile data/PET/rom4b80.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/rom4b80.vrs run 0644
installfile data/PET/rom4g40.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/rom4g40.vrs run 0644
installfile data/PET/white.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/white.vpl run 0644
installfile data/PET/x11_bdep.vkm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/x11_bdep.vkm run 0644
installfile data/PET/x11_bdes.vkm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/x11_bdes.vkm run 0644
installfile data/PET/x11_bgrs.vkm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/x11_bgrs.vkm run 0644
installfile data/PET/x11_buks.vkm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PET/x11_buks.vkm run 0644
installfile data/PLUS4/3plus1hi viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PLUS4/3plus1hi run 0644
installfile data/PLUS4/3plus1lo viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PLUS4/3plus1lo run 0644
installfile data/PLUS4/basic viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PLUS4/basic run 0644
installfile data/PLUS4/default.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PLUS4/default.vpl run 0644
installfile data/PLUS4/default.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PLUS4/default.vrs run 0644
installfile data/PLUS4/kernal viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PLUS4/kernal run 0644
installfile data/PLUS4/vice.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PLUS4/vice.vpl run 0644
installfile data/PLUS4/x11_pos.vkm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PLUS4/x11_pos.vkm run 0644
installfile data/PLUS4/x11_sym.vkm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PLUS4/x11_sym.vkm run 0644
installfile data/PRINTER/cbm1526 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PRINTER/cbm1526 run 0644
installfile data/PRINTER/mps801 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PRINTER/mps801 run 0644
installfile data/PRINTER/mps803 viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PRINTER/mps803 run 0644
installfile data/PRINTER/mps803.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PRINTER/mps803.vpl run 0644
installfile data/PRINTER/nl10-cbm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/PRINTER/nl10-cbm run 0644
installfile data/VIC20/basic viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/VIC20/basic run 0644
installfile data/VIC20/chargen viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/VIC20/chargen run 0644
installfile data/VIC20/default.vpl viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/VIC20/default.vpl run 0644
installfile data/VIC20/default.vrs viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/VIC20/default.vrs run 0644
installfile data/VIC20/kernal viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/VIC20/kernal run 0644
installfile data/VIC20/x11_pos.vkm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/VIC20/x11_pos.vkm run 0644
installfile data/VIC20/x11_sym.vkm viceplus/viceplus-RUN runtmp /usr/local/lib/viceplus/VIC20/x11_sym.vkm run 0644

# Install and prepare viceplus-MAN
mantotal=0
installfile man/c1541.1 viceplus/viceplus-MAN mantmp /usr/local/man/man1/c1541.1 man 0644
installfile man/petcat.1 viceplus/viceplus-MAN mantmp /usr/local/man/man1/petcat.1 man 0644
installfile man/vice.1 viceplus/viceplus-MAN mantmp /usr/local/man/man1/vice.1 man 0644

# Make catalog/dfiles/INDEX
cat >catalog/dfiles/INDEX <<_END
distribution
layout_version 1.0
data_model_revision 2.40
uuid $UUID
mod_time $DATESTRING
create_time $DATESTRING
path_max 255
name_max 100
media 
sequence_number 1
_END

# Make catalog/dfiles/INFO
check=`cksum catalog/dfiles/INDEX`
getsize $check

cat >catalog/dfiles/INFO.1 <<_END
control_file
path INDEX
size $gotsize
mode 0444
mtime $DATESTRING
tag INDEX
control_file
path INFO
_END

echo >catalog/dfiles/INFO.2 size xxx

cat >catalog/dfiles/INFO.3 <<_END
mode 0444
mtime $DATESTRING
tag INFO
_END

check1=`cksum catalog/dfiles/INFO.1`
check2=`cksum catalog/dfiles/INFO.2`
check3=`cksum catalog/dfiles/INFO.3`
getsize $check1
size1=$gotsize
getsize $check2
size2=$gotsize
getsize $check3
size3=$gotsize
totalsize=`expr $size1 + $size2 + $size3 + 60`
echo >catalog/dfiles/INFO.2 size $totalsize
cat >catalog/dfiles/INFO catalog/dfiles/INFO.1 catalog/dfiles/INFO.2 catalog/dfiles/INFO.3
rm -f catalog/dfiles/INFO.*

# Make catalog/viceplus/pfiles/INDEX
cat >catalog/viceplus/pfiles/INDEX <<_END
product
tag viceplus
data_model_revision 2.40
instance_id 1
control_directory viceplus
revision $DTVVERSION
title "viceplus"
mod_time $DATESTRING
create_time $DATESTRING
architecture $UNAMECONCAT
machine_type *
os_name $UNAMES
os_release $UNAMER
os_version *
directory /usr/local
all_filesets viceplus-MAN viceplus-RUN 
is_locatable false
subproduct
tag Manuals
contents viceplus-MAN 
subproduct
tag Runtime
contents viceplus-RUN 
_END

# Make catalog/viceplus/pfiles/INFO
check=`cksum catalog/viceplus/pfiles/INDEX`
getsize $check

cat >catalog/viceplus/pfiles/INFO.1 <<_END
control_file
path INDEX
size $gotsize
mode 0444
mtime $DATESTRING
tag INDEX
control_file
path INFO
_END

echo >catalog/viceplus/pfiles/INFO.2 size xxx

cat >catalog/viceplus/pfiles/INFO.3 <<_END
mode 0444
mtime $DATESTRING
tag INFO
_END

check1=`cksum catalog/viceplus/pfiles/INFO.1`
check2=`cksum catalog/viceplus/pfiles/INFO.2`
check3=`cksum catalog/viceplus/pfiles/INFO.3`
getsize $check1
size1=$gotsize
getsize $check2
size2=$gotsize
getsize $check3
size3=$gotsize
totalsize=`expr $size1 + $size2 + $size3 + 60`
echo >catalog/viceplus/pfiles/INFO.2 size $totalsize
cat >catalog/viceplus/pfiles/INFO catalog/viceplus/pfiles/INFO.1 catalog/viceplus/pfiles/INFO.2 catalog/viceplus/pfiles/INFO.3
rm -f -r catalog/viceplus/pfiles/INFO.*

# Make catalog/viceplus/viceplus-MAN/INDEX.1|2|3 parts

cat >catalog/viceplus/viceplus-MAN/INDEX.1 <<_END
fileset
tag viceplus-MAN
data_model_revision 2.40
instance_id 1
control_directory viceplus-MAN
_END

echo >catalog/viceplus/viceplus-MAN/INDEX.2 size xxxxx

cat >catalog/viceplus/viceplus-MAN/INDEX.3 <<_END
mod_time $DATESTRING
create_time $DATESTRING
state available
_END

check1=`cksum catalog/viceplus/viceplus-MAN/INDEX.1`
check2=`cksum catalog/viceplus/viceplus-MAN/INDEX.2`
check3=`cksum catalog/viceplus/viceplus-MAN/INDEX.3`
getsize $check1
size1=$gotsize
getsize $check2
size2=$gotsize
getsize $check3
size3=$gotsize
indexsize=`expr $size1 + $size2 + $size3`

# Make catalog/viceplus/viceplus-MAN/INFO

cat >catalog/viceplus/viceplus-MAN/INFO.1 <<_END
control_file
path INDEX
size $indexsize
mode 0444
mtime $DATESTRING
tag INDEX
control_file
path INFO
_END

echo >catalog/viceplus/viceplus-MAN/INFO.2 size xxxx

cat >catalog/viceplus/viceplus-MAN/INFO.0 <<_END
mode 0444
mtime $DATESTRING
tag INFO
_END

cat >catalog/viceplus/viceplus-MAN/INFO.3 catalog/viceplus/viceplus-MAN/INFO.0 mantmp
rm -f mantmp

check1=`cksum catalog/viceplus/viceplus-MAN/INFO.1`
check2=`cksum catalog/viceplus/viceplus-MAN/INFO.2`
check3=`cksum catalog/viceplus/viceplus-MAN/INFO.3`
getsize $check1
size1=$gotsize
getsize $check2
size2=$gotsize
getsize $check3
size3=$gotsize
infosize=`expr $size1 + $size2 + $size3 + 59`

echo >catalog/viceplus/viceplus-MAN/INFO.2 size $infosize

cat >catalog/viceplus/viceplus-MAN/INFO catalog/viceplus/viceplus-MAN/INFO.1 catalog/viceplus/viceplus-MAN/INFO.2 catalog/viceplus/viceplus-MAN/INFO.3
rm -f catalog/viceplus/viceplus-MAN/INFO.*

# Make catalog/viceplus/viceplus-MAN/INDEX

mansize=`expr $mantotal + $indexsize + $infosize`
echo >catalog/viceplus/viceplus-MAN/INDEX.2 size $mansize

cat >catalog/viceplus/viceplus-MAN/INDEX catalog/viceplus/viceplus-MAN/INDEX.1 catalog/viceplus/viceplus-MAN/INDEX.2 catalog/viceplus/viceplus-MAN/INDEX.3
rm -f catalog/viceplus/viceplus-MAN/INDEX.*

# Make catalog/viceplus/viceplus-RUN/INDEX.1|2|3 parts

cat >catalog/viceplus/viceplus-RUN/INDEX.1 <<_END
fileset
tag viceplus-RUN
data_model_revision 2.40
instance_id 1
control_directory viceplus-RUN
_END

echo >catalog/viceplus/viceplus-RUN/INDEX.2 size xxxxxxxx

cat >catalog/viceplus/viceplus-RUN/INDEX.3 <<_END
mod_time $DATESTRING
create_time $DATESTRING
state available
_END

check1=`cksum catalog/viceplus/viceplus-RUN/INDEX.1`
check2=`cksum catalog/viceplus/viceplus-RUN/INDEX.2`
check3=`cksum catalog/viceplus/viceplus-RUN/INDEX.3`
getsize $check1
size1=$gotsize
getsize $check2
size2=$gotsize
getsize $check3
size3=$gotsize
indexsize=`expr $size1 + $size2 + $size3`

# Make catalog/viceplus/viceplus-RUN/INFO

cat >catalog/viceplus/viceplus-RUN/INFO.1 <<_END
control_file
path INDEX
size $indexsize
mode 0444
mtime $DATESTRING
tag INDEX
control_file
path INFO
_END

echo >catalog/viceplus/viceplus-RUN/INFO.2 size xxxxx

cat >catalog/viceplus/viceplus-RUN/INFO.0 <<_END
mode 0444
mtime $DATESTRING
tag INFO
_END

cat >catalog/viceplus/viceplus-RUN/INFO.3 catalog/viceplus/viceplus-RUN/INFO.0 runtmp
rm -f runtmp

check1=`cksum catalog/viceplus/viceplus-RUN/INFO.1`
check2=`cksum catalog/viceplus/viceplus-RUN/INFO.2`
check3=`cksum catalog/viceplus/viceplus-RUN/INFO.3`
getsize $check1
size1=$gotsize
getsize $check2
size2=$gotsize
getsize $check3
size3=$gotsize
infosize=`expr $size1 + $size2 + $size3 + 59`

echo >catalog/viceplus/viceplus-RUN/INFO.2 size $infosize

cat >catalog/viceplus/viceplus-RUN/INFO catalog/viceplus/viceplus-RUN/INFO.1 catalog/viceplus/viceplus-RUN/INFO.2 catalog/viceplus/viceplus-RUN/INFO.3
rm -f catalog/viceplus/viceplus-RUN/INFO.*

# Make catalog/viceplus/viceplus-RUN/INDEX

runsize=`expr $runtotal + $indexsize + $infosize`
echo >catalog/viceplus/viceplus-RUN/INDEX.2 size $runsize

cat >catalog/viceplus/viceplus-RUN/INDEX catalog/viceplus/viceplus-RUN/INDEX.1 catalog/viceplus/viceplus-RUN/INDEX.2 catalog/viceplus/viceplus-RUN/INDEX.3
rm -f catalog/viceplus/viceplus-RUN/INDEX.*

cat >catalog/INDEX <<_END
distribution
layout_version 1.0
data_model_revision 2.40
uuid $UUID
mod_time $DATESTRING
create_time $DATESTRING
path_max 255
name_max 100
media 
sequence_number 1
product
tag viceplus
data_model_revision 2.40
instance_id 1
control_directory vice
revision $DTVVERSION
title "viceplus"
description "VICEplus is a program that runs on a Unix, MS-DOS, Win32, OS/2,
Acorn RISC OS, QNX 6.x, AmigaOS or BeOS machine and executes programs
intended for the old 8-bit computers. The current version emulates the C64,
the C128, the VIC20, all the PET models (except the SuperPET 9000, which is
out of line anyway), the PLUS4 and the CBM-II (aka C610).
mod_time $DATESTRING
create_time $DATESTRING
architecture $UNAMECONCAT 
machine_type $UNAMEM
os_name $UNAMES
os_release $UNAMER
os_version *
directory /usr/local
all_filesets viceplus-MAN viceplus-RUN 
is_locatable false
subproduct
tag Manuals
contents viceplus-MAN 
subproduct
tag Runtime
contents viceplus-RUN 
fileset
tag viceplus-MAN
data_model_revision 2.40
instance_id 1
control_directory viceplus-MAN
size $mansize
mod_time $DATESTRING
create_time $DTESTRING
state available
fileset
tag viceplus-RUN
data_model_revision 2.40
instance_id 1
control_directory viceplus-RUN
size $runsize
mod_time $DATESTRING
create_time $DATESTRING
state available
_END

if test x"$ZIPKIND" = "xzip"; then
  cputouse=`echo $CPU | cut -c1-4`
  ostouse=`echo $SYSTEM | cut -c5-`
  tar cf viceplus-$DTVVERSION-$cputouse-$ostouse.depot catalog viceplus
  gzip viceplus-$DTVVERSION-$cputouse-$ostouse.depot
  rm -f -r catalog viceplus
  echo HPUX port binary depot generated as viceplus-$DTVVERSION-$cputouse-$ostouse.depot.gz
else
  echo HPUX port binary destribution directory generated as catalog and and viceplus
fi
